import QtQuick
import QtQuick.Window
import QtQuick.Controls
import QtMultimedia

Window {
    width: 853
    height: 480
    minimumWidth: 400
    minimumHeight: 380
    visible: true
    title: qsTr("Winds of Paradise Launcher")

    // This is the bridge between Python and QML
    // target needs to match the instantiated object ui = UI()
    // Include function on[SignaName] for every signal you'll rasise from Python
    // The magic is done by pyside to match on[SignalName] to [SignalName] in Python
    // This is the best way I've found so far to interact with QtControls
    Connections {
        target: ui

        // Anything you want to run as soon as this window opens can go here
        Component.onCompleted: function() {
            // Timer allow the form the load before we start updating. Purely cosmetic.
            timer.interval = 1000
            timer.repeat = false
            timer.triggered.connect(ui.startUpdates)
            timer.start()
        }

        function onLauncherVersionChanged(version) {
            txtLauncherVersion.text = "Winds of Paradise Launcher Version: "
            txtLauncherVersion.text += version
        }

        function onOkToReinstallChanged(enabled) {
            reinstallButton.enabled = enabled;
        }

        function onOkToPlayChanged(enabled) {
            playButton.enabled = enabled;
        }

        function onProgressBarIndeterminateChanged(indeterminate) {
            progressBar.indeterminate = indeterminate
        }

        function onProgressUpdated(amount) {
            progressBar.value = amount
        }

        function onStatusTextChanged(text) {
            textField.text = text
        }
    }

    Timer {
        id: timer
    }

     AnimatedImage {
        id: image
        x: 0
        y: 0
        width: parent.width
        height: parent.height
        source: "../images/intro.gif"
        fillMode: Image.Image.PreserveAspectCrop
    }

    // // Audio {
    // //     id: waves
    // //     source: "audio/ocean-waves.mp3"
    // //     loops: Audio.Infinite
    // //     autoPlay: true
    // // }

    // Audio {
    //     id: music
    //     source: "../audio/With love from Vertex Studio (16).mp3"
    //     autoPlay: true
    // }

    MediaPlayer {
        id: music
        audioOutput: AudioOutput {}
        source: "../audio/with-love-from-vertex-Studio-16.mp3"
        Component.onCompleted: { play() }
    }


    Text {
        id: title
        x: parent.width * .05
        y: 11
        width: parent.width * .9
        height: 60
        color: "#ffffff"
        text: qsTr("Winds of Paradise Launcher")
        font.pixelSize: 30
        horizontalAlignment: Text.AlignHCenter
        verticalAlignment: Text.AlignVCenter
        minimumPixelSize: 12
    }

    TextField {
        id: textField
        x: parent.width * .05
        y: 98
        width: parent.width * .9
        height: 40
        // placeholderText: qsTr("Let's do this!")
        text: "Let's do this!"
        readOnly: true
    }

    Button {
        id: playButton
        x: (parent.width / 2) - (width / 2)
        y: 250
        text: qsTr("Play")
        enabled: false
        onClicked: {
            music.stop()
            ui.play()
        }
    }

    Button {
        id: reinstallButton
        x: (parent.width / 2) - (width / 2)
        y: 300
        text: qsTr("Reinstall")
        enabled: false
        onClicked: {
            ui.reinstallGame();
        }
    }

    ProgressBar {
        id: progressBar
        x: parent.width * .05
        y: 170
        width: parent.width * .9
        height: 42
        // Use indeterminate when unzipping
        // indeterminate: true
        wheelEnabled: false
        value: 0.0
    }

    Text {
        id: feedbackLink
        x: (parent.width / 2) - (width / 2)
        y: 350
        // anchors.centerIn: parent
        text: "<a href='http://bit.ly/windsfeedback'>Feedback</a>"
        onLinkActivated: Qt.openUrlExternally(link)

        MouseArea {
            anchors.fill: parent
            acceptedButtons: Qt.NoButton // we don't want to eat clicks on the Text
            cursorShape: parent.hoveredLink ? Qt.PointingHandCursor : Qt.ArrowCursor
        }
    }

    Text {
        id: txtLauncherVersion
        x: parent.width * .05
        y: parent.height - 50
        text: qsTr("Version")
        color: "#ffffff"
        font.pixelSize: 12
        Component.onCompleted: function() {
            // ui.setLauncherVersion()
            ui.setLauncherVersion()
        }
    }
}

/*##^##
Designer {
    D{i:0;autoSize:true;height:480;width:640}
}
##^##*/
